@@ -45,7 +45,9 @@ def ensure_directories(*args,**kwargs):
             dirname = os.path.dirname(arg_str)
             directories.append(dirname)
     safe_directories = get_dir_filter_kwargs(**kwargs)
-    directories+= make_list(safe_directories.get('directories',get_initial_caller_dir()))
+    safe_dirs = safe_directories.get('directories')
+    safe_dirs = if_none_default(safe_dirs or None,default = get_initial_caller_dir())
+    directories+= make_list(safe_dirs)
     return list(set([r for r in directories if r]))
 def get_proper_type_str(string):
     if not string:
