@@ -3,8 +3,7 @@
 from __future__ import annotations
 from .find_collect import *
 from ..imports import *
-ABSPATH = os.path.abspath(__file__)
-ABSROOT = os.path.dirname(ABSPATH)
+
 def caller_path():
     frame = inspect.stack()[1]
     return os.path.abspath(frame.filename)
@@ -228,7 +227,7 @@ def apply_inits(ROOT):
     if if_fun_dir != None:
         
         if if_fun_dir:
-           filepaths = collect_filepaths(allowed_exts='.py',add=True)
+           filepaths = collect_filepaths(FUNCS_DIR,allowed_exts='.py',add=True)
             
         else:
             filepaths = [FUNCS_DIR]
